==> zio-aws-elastictranscoder_3-5.17.102.9-sources.jar: zio/aws/elastictranscoder/model/UpdatePipelineResponse.scala <==
package zio.aws.elastictranscoder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdatePipelineResponse(
    pipeline: Option[zio.aws.elastictranscoder.model.Pipeline] = None,
    warnings: Option[Iterable[zio.aws.elastictranscoder.model.Warning]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineResponse = {
    import UpdatePipelineResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineResponse
      .builder()
      .optionallyWith(pipeline.map(value => value.buildAwsValue()))(_.pipeline)
      .optionallyWith(
        warnings.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.warnings)
      .build()
  }
  def asReadOnly
      : zio.aws.elastictranscoder.model.UpdatePipelineResponse.ReadOnly =
    zio.aws.elastictranscoder.model.UpdatePipelineResponse.wrap(buildAwsValue())
}
object UpdatePipelineResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elastictranscoder.model.UpdatePipelineResponse =
      zio.aws.elastictranscoder.model.UpdatePipelineResponse(
        pipeline.map(value => value.asEditable),
        warnings.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def pipeline: Option[zio.aws.elastictranscoder.model.Pipeline.ReadOnly]
    def warnings: Option[List[zio.aws.elastictranscoder.model.Warning.ReadOnly]]
    def getPipeline: ZIO[
      Any,
      AwsError,
      zio.aws.elastictranscoder.model.Pipeline.ReadOnly
    ] = AwsError.unwrapOptionField("pipeline", pipeline)
    def getWarnings: ZIO[Any, AwsError, List[
      zio.aws.elastictranscoder.model.Warning.ReadOnly
    ]] = AwsError.unwrapOptionField("warnings", warnings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineResponse
  ) extends zio.aws.elastictranscoder.model.UpdatePipelineResponse.ReadOnly {
    override val pipeline
        : Option[zio.aws.elastictranscoder.model.Pipeline.ReadOnly] = scala
      .Option(impl.pipeline())
      .map(value => zio.aws.elastictranscoder.model.Pipeline.wrap(value))
    override val warnings
        : Option[List[zio.aws.elastictranscoder.model.Warning.ReadOnly]] = scala
      .Option(impl.warnings())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elastictranscoder.model.Warning.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineResponse
  ): zio.aws.elastictranscoder.model.UpdatePipelineResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elastictranscoder_3-5.17.195.3-sources.jar: zio/aws/elastictranscoder/model/UpdatePipelineResponse.scala <==
package zio.aws.elastictranscoder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdatePipelineResponse(
    pipeline: Optional[zio.aws.elastictranscoder.model.Pipeline] =
      Optional.Absent,
    warnings: Optional[Iterable[zio.aws.elastictranscoder.model.Warning]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineResponse = {
    import UpdatePipelineResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineResponse
      .builder()
      .optionallyWith(pipeline.map(value => value.buildAwsValue()))(_.pipeline)
      .optionallyWith(
        warnings.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.warnings)
      .build()
  }
  def asReadOnly
      : zio.aws.elastictranscoder.model.UpdatePipelineResponse.ReadOnly =
    zio.aws.elastictranscoder.model.UpdatePipelineResponse.wrap(buildAwsValue())
}
object UpdatePipelineResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elastictranscoder.model.UpdatePipelineResponse =
      zio.aws.elastictranscoder.model.UpdatePipelineResponse(
        pipeline.map(value => value.asEditable),
        warnings.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def pipeline: Optional[zio.aws.elastictranscoder.model.Pipeline.ReadOnly]
    def warnings
        : Optional[List[zio.aws.elastictranscoder.model.Warning.ReadOnly]]
    def getPipeline: ZIO[
      Any,
      AwsError,
      zio.aws.elastictranscoder.model.Pipeline.ReadOnly
    ] = AwsError.unwrapOptionField("pipeline", pipeline)
    def getWarnings: ZIO[Any, AwsError, List[
      zio.aws.elastictranscoder.model.Warning.ReadOnly
    ]] = AwsError.unwrapOptionField("warnings", warnings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineResponse
  ) extends zio.aws.elastictranscoder.model.UpdatePipelineResponse.ReadOnly {
    override val pipeline
        : Optional[zio.aws.elastictranscoder.model.Pipeline.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.pipeline())
        .map(value => zio.aws.elastictranscoder.model.Pipeline.wrap(value))
    override val warnings
        : Optional[List[zio.aws.elastictranscoder.model.Warning.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.warnings())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.elastictranscoder.model.Warning.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineResponse
  ): zio.aws.elastictranscoder.model.UpdatePipelineResponse.ReadOnly =
    new Wrapper(impl)
}
